@@ -103,6 +103,8 @@
 *        Added Clean attribute.
 *     19-MAR-2004 (DSB):
 *        Added astPutCards function.
+*     20-NOV-2017 (DSB):
+*        Added SipReplace attribute.
 *-
 */
 
@@ -176,7 +178,10 @@ typedef struct AstFitsChan {
    int tabok;       /* Support -TAB algorithm? */
    int cdmatrix;    /* Use a CD matrix in FITS-WCS Encoding? */
    int polytan;     /* Use distorted TAN convention? */
+   int sipok;       /* Use SIP distortion convention? */
    int carlin;      /* Use linear CAR mappings? */
+   int sipreplace;  /* Replace SIP inverse coefficients? */
+   double fitstol;  /* Max departure from linearity, in pixels */
    int iwc;         /* Include an IWC Frame? */
    int clean;       /* Remove used cards even if an error occurs? */
    int fitsdigits;  /* No. of decmial places in formatted floating point keyword values */
@@ -290,6 +295,16 @@ typedef struct AstFitsChanVtab {
    void (* SetCarLin)( AstFitsChan *, int, int * );
    void (* ClearCarLin)( AstFitsChan *, int * );
 
+   int (* GetSipReplace)( AstFitsChan *, int * );
+   int (* TestSipReplace)( AstFitsChan *, int * );
+   void (* SetSipReplace)( AstFitsChan *, int, int * );
+   void (* ClearSipReplace)( AstFitsChan *, int * );
+
+   double (* GetFitsTol)( AstFitsChan *, int * );
+   int (* TestFitsTol)( AstFitsChan *, int * );
+   void (* SetFitsTol)( AstFitsChan *, double, int * );
+   void (* ClearFitsTol)( AstFitsChan *, int * );
+
    int (* GetNcard)( AstFitsChan *, int * );
 
    int (* GetCardType)( AstFitsChan *, int * );
@@ -325,6 +340,11 @@ typedef struct AstFitsChanVtab {
    void (* SetPolyTan)( AstFitsChan *, int, int * );
    void (* ClearPolyTan)( AstFitsChan *, int * );
 
+   int (* GetSipOK)( AstFitsChan *, int * );
+   int (* TestSipOK)( AstFitsChan *, int * );
+   void (* SetSipOK)( AstFitsChan *, int, int * );
+   void (* ClearSipOK)( AstFitsChan *, int * );
+
    int (* GetIwc)( AstFitsChan *, int * );
    int (* TestIwc)( AstFitsChan *, int * );
    void (* SetIwc)( AstFitsChan *, int, int * );
@@ -509,11 +529,26 @@ void astInitFitsChanGlobals_( AstFitsChanGlobals * );
    void astSetPolyTan_( AstFitsChan *, int, int * );
    void astClearPolyTan_( AstFitsChan *, int * );
 
+   int astGetSipReplace_( AstFitsChan *, int * );
+   int astTestSipReplace_( AstFitsChan *, int * );
+   void astSetSipReplace_( AstFitsChan *, int, int * );
+   void astClearSipReplace_( AstFitsChan *, int * );
+
+   int astGetSipOK_( AstFitsChan *, int * );
+   int astTestSipOK_( AstFitsChan *, int * );
+   void astSetSipOK_( AstFitsChan *, int, int * );
+   void astClearSipOK_( AstFitsChan *, int * );
+
    int astGetCarLin_( AstFitsChan *, int * );
    int astTestCarLin_( AstFitsChan *, int * );
    void astSetCarLin_( AstFitsChan *, int, int * );
    void astClearCarLin_( AstFitsChan *, int * );
 
+   double astGetFitsTol_( AstFitsChan *, int * );
+   int astTestFitsTol_( AstFitsChan *, int * );
+   void astSetFitsTol_( AstFitsChan *, double, int * );
+   void astClearFitsTol_( AstFitsChan *, int * );
+
    int astGetIwc_( AstFitsChan *, int * );
    int astTestIwc_( AstFitsChan *, int * );
    void astSetIwc_( AstFitsChan *, int, int * );
@@ -780,6 +815,15 @@ astINVOKE(V,astSetPolyTan_(astCheckFitsChan(this),value,STATUS_PTR))
 #define astTestPolyTan(this) \
 astINVOKE(V,astTestPolyTan_(astCheckFitsChan(this),STATUS_PTR))
 
+#define astClearSipOK(this) \
+astINVOKE(V,astClearSipOK_(astCheckFitsChan(this),STATUS_PTR))
+#define astGetSipOK(this) \
+astINVOKE(V,astGetSipOK_(astCheckFitsChan(this),STATUS_PTR))
+#define astSetSipOK(this,value) \
+astINVOKE(V,astSetSipOK_(astCheckFitsChan(this),value,STATUS_PTR))
+#define astTestSipOK(this) \
+astINVOKE(V,astTestSipOK_(astCheckFitsChan(this),STATUS_PTR))
+
 #define astClearCarLin(this) \
 astINVOKE(V,astClearCarLin_(astCheckFitsChan(this),STATUS_PTR))
 #define astGetCarLin(this) \
@@ -789,6 +833,24 @@ astINVOKE(V,astSetCarLin_(astCheckFitsChan(this),carln,STATUS_PTR))
 #define astTestCarLin(this) \
 astINVOKE(V,astTestCarLin_(astCheckFitsChan(this),STATUS_PTR))
 
+#define astClearSipReplace(this) \
+astINVOKE(V,astClearSipReplace_(astCheckFitsChan(this),STATUS_PTR))
+#define astGetSipReplace(this) \
+astINVOKE(V,astGetSipReplace_(astCheckFitsChan(this),STATUS_PTR))
+#define astSetSipReplace(this,siprep) \
+astINVOKE(V,astSetSipReplace_(astCheckFitsChan(this),siprep,STATUS_PTR))
+#define astTestSipReplace(this) \
+astINVOKE(V,astTestSipReplace_(astCheckFitsChan(this),STATUS_PTR))
+
+#define astClearFitsTol(this) \
+astINVOKE(V,astClearFitsTol_(astCheckFitsChan(this),STATUS_PTR))
+#define astGetFitsTol(this) \
+astINVOKE(V,astGetFitsTol_(astCheckFitsChan(this),STATUS_PTR))
+#define astSetFitsTol(this,fitstl) \
+astINVOKE(V,astSetFitsTol_(astCheckFitsChan(this),fitstl,STATUS_PTR))
+#define astTestFitsTol(this) \
+astINVOKE(V,astTestFitsTol_(astCheckFitsChan(this),STATUS_PTR))
+
 #define astClearClean(this) \
 astINVOKE(V,astClearClean_(astCheckFitsChan(this),STATUS_PTR))
 #define astGetClean(this) \
